@@ -1,4 +1,3 @@
-
 ## -----------------------------------------------------------------------
 ##
 ##   IGraph R package
@@ -66,14 +65,26 @@
 #' @param options A named list containing the parameters for the SVD
 #'   computation algorithm in ARPACK. By default, the list of values is assigned
 #'   the values given by [arpack_defaults()].
-#' @return A list containing with entries: \item{X}{Estimated latent positions,
-#'   an `n` times `no` matrix, `n` is the number of vertices.}
-#'   \item{Y}{`NULL` for undirected graphs, the second half of the latent
-#'   positions for directed graphs, an `n` times `no` matrix, `n`
-#'   is the number of vertices.} \item{D}{The eigenvalues (for undirected graphs)
-#'   or the singular values (for directed graphs) calculated by the algorithm.}
-#'   \item{options}{A named list, information about the underlying ARPACK
-#'   computation. See [arpack()] for the details.}
+#' @return A list containing with entries:
+#'   \describe{
+#'     \item{X}{
+#'       Estimated latent positions,
+#'       an `n` times `no` matrix, `n` is the number of vertices.
+#'     }
+#'     \item{Y}{
+#'       `NULL` for undirected graphs, the second half of the latent
+#'       positions for directed graphs, an `n` times `no` matrix, `n`
+#'       is the number of vertices.
+#'     }
+#'     \item{D}{
+#'       The eigenvalues (for undirected graphs)
+#'       or the singular values (for directed graphs) calculated by the algorithm.
+#'     }
+#'     \item{options}{
+#'       A named list, information about the underlying ARPACK
+#'       computation. See [arpack()] for the details.
+#'     }
+#'   }
 #' @seealso [sample_dot_product()]
 #' @references Sussman, D.L., Tang, M., Fishkind, D.E., Priebe, C.E.  A
 #' Consistent Adjacency Spectral Embedding for Stochastic Blockmodel Graphs,
@@ -90,6 +101,7 @@
 #' embed <- embed_adjacency_matrix(RDP, 5)
 #' @family embedding
 #' @export
+#' @cdocs igraph_adjacency_spectral_embedding
 embed_adjacency_matrix <- adjacency_spectral_embedding_impl
 
 
@@ -151,6 +163,7 @@ embed_adjacency_matrix <- adjacency_spectral_embedding_impl
 #'
 #' @family embedding
 #' @export
+#' @cdocs igraph_dim_select
 dim_select <- dim_select_impl
 
 
@@ -204,14 +217,26 @@ dim_select <- dim_select_impl
 #' @param options A named list containing the parameters for the SVD
 #'   computation algorithm in ARPACK. By default, the list of values is assigned
 #'   the values given by [arpack_defaults()].
-#' @return A list containing with entries: \item{X}{Estimated latent positions,
-#'   an `n` times `no` matrix, `n` is the number of vertices.}
-#'   \item{Y}{`NULL` for undirected graphs, the second half of the latent
-#'   positions for directed graphs, an `n` times `no` matrix, `n`
-#'   is the number of vertices.} \item{D}{The eigenvalues (for undirected graphs)
-#'   or the singular values (for directed graphs) calculated by the algorithm.}
-#'   \item{options}{A named list, information about the underlying ARPACK
-#'   computation. See [arpack()] for the details.}
+#' @return A list containing with entries:
+#'   \describe{
+#'     \item{X}{
+#'       Estimated latent positions,
+#'       an `n` times `no` matrix, `n` is the number of vertices.
+#'     }
+#'     \item{Y}{
+#'       `NULL` for undirected graphs, the second half of the latent
+#'       positions for directed graphs, an `n` times `no` matrix, `n`
+#'       is the number of vertices.
+#'     }
+#'     \item{D}{
+#'       The eigenvalues (for undirected graphs)
+#'       or the singular values (for directed graphs) calculated by the algorithm.
+#'     }
+#'     \item{options}{
+#'       A named list, information about the underlying ARPACK
+#'       computation. See [arpack()] for the details.
+#'     }
+#'   }
 #' @author Gabor Csardi \email{csardi.gabor@@gmail.com}
 #' @seealso [embed_adjacency_matrix()],
 #' [sample_dot_product()]
@@ -230,6 +255,7 @@ dim_select <- dim_select_impl
 #' RDP <- sample_dot_product(lpvs)
 #' embed <- embed_laplacian_matrix(RDP, 5)
 #' @family embedding
+#' @cdocs igraph_laplacian_spectral_embedding
 embed_laplacian_matrix <- laplacian_spectral_embedding_impl
 
 
@@ -262,17 +288,13 @@ embed_laplacian_matrix <- laplacian_spectral_embedding_impl
 #' })
 #' vec.norm
 sample_sphere_surface <- function(dim, n = 1, radius = 1, positive = TRUE) {
-  # Argument checks
-  dim <- as.numeric(dim)
-  n <- as.numeric(n)
-  radius <- as.numeric(radius)
-  positive <- as.logical(positive)
-
-  on.exit(.Call(R_igraph_finalizer))
-  # Function call
-  res <- .Call(R_igraph_sample_sphere_surface, dim, n, radius, positive)
-
-  res
+  # Use the _impl function
+  sample_sphere_surface_impl(
+    dim = dim,
+    n = n,
+    radius = radius,
+    positive = positive
+  )
 }
 
 #' Sample vectors uniformly from the volume of a sphere
@@ -304,17 +326,13 @@ sample_sphere_surface <- function(dim, n = 1, radius = 1, positive = TRUE) {
 #' })
 #' vec.norm
 sample_sphere_volume <- function(dim, n = 1, radius = 1, positive = TRUE) {
-  # Argument checks
-  dim <- as.numeric(dim)
-  n <- as.numeric(n)
-  radius <- as.numeric(radius)
-  positive <- as.logical(positive)
-
-  on.exit(.Call(R_igraph_finalizer))
-  # Function call
-  res <- .Call(R_igraph_sample_sphere_volume, dim, n, radius, positive)
-
-  res
+  # Use the _impl function
+  sample_sphere_volume_impl(
+    dim = dim,
+    n = n,
+    radius = radius,
+    positive = positive
+  )
 }
 
 #' Sample from a Dirichlet distribution
@@ -341,13 +359,6 @@ sample_sphere_volume <- function(dim, n = 1, radius = 1, positive = TRUE) {
 #' RDP.graph.2 <- sample_dot_product(lpvs.dir)
 #' colSums(lpvs.dir)
 sample_dirichlet <- function(n, alpha) {
-  # Argument checks
-  n <- as.numeric(n)
-  alpha <- as.numeric(alpha)
-
-  on.exit(.Call(R_igraph_finalizer))
-  # Function call
-  res <- .Call(R_igraph_sample_dirichlet, n, alpha)
-
-  res
+  # Use the _impl function
+  sample_dirichlet_impl(n = n, alpha = alpha)
 }
