@@ -1,15 +1,15 @@
-
 #' Check whether a graph is directed
 #'
 #' @description
 #' `r lifecycle::badge("deprecated")`
 #'
-#' `is.directed()` was renamed to `is_directed()` to create a more
+#' `is.directed()` was renamed to [is_directed()] to create a more
 #' consistent API.
 #' @inheritParams is_directed
 #' @keywords internal
 #' @export
-is.directed <- function(graph) { # nocov start
+is.directed <- function(graph) {
+  # nocov start
   lifecycle::deprecate_soft("2.0.0", "is.directed()", "is_directed()")
   is_directed(graph = graph)
 } # nocov end
@@ -19,12 +19,13 @@ is.directed <- function(graph) { # nocov start
 #' @description
 #' `r lifecycle::badge("deprecated")`
 #'
-#' `delete.vertices()` was renamed to `delete_vertices()` to create a more
+#' `delete.vertices()` was renamed to [delete_vertices()] to create a more
 #' consistent API.
 #' @inheritParams delete_vertices
 #' @keywords internal
 #' @export
-delete.vertices <- function(graph, v) { # nocov start
+delete.vertices <- function(graph, v) {
+  # nocov start
   lifecycle::deprecate_soft("2.0.0", "delete.vertices()", "delete_vertices()")
   delete_vertices(graph = graph, v = v)
 } # nocov end
@@ -34,12 +35,13 @@ delete.vertices <- function(graph, v) { # nocov start
 #' @description
 #' `r lifecycle::badge("deprecated")`
 #'
-#' `delete.edges()` was renamed to `delete_edges()` to create a more
+#' `delete.edges()` was renamed to [delete_edges()] to create a more
 #' consistent API.
 #' @inheritParams delete_edges
 #' @keywords internal
 #' @export
-delete.edges <- function(graph, edges) { # nocov start
+delete.edges <- function(graph, edges) {
+  # nocov start
   lifecycle::deprecate_soft("2.0.0", "delete.edges()", "delete_edges()")
   delete_edges(graph = graph, edges = edges)
 } # nocov end
@@ -49,12 +51,13 @@ delete.edges <- function(graph, edges) { # nocov start
 #' @description
 #' `r lifecycle::badge("deprecated")`
 #'
-#' `add.vertices()` was renamed to `add_vertices()` to create a more
+#' `add.vertices()` was renamed to [add_vertices()] to create a more
 #' consistent API.
 #' @inheritParams add_vertices
 #' @keywords internal
 #' @export
-add.vertices <- function(graph, nv, ..., attr = list()) { # nocov start
+add.vertices <- function(graph, nv, ..., attr = list()) {
+  # nocov start
   lifecycle::deprecate_soft("2.0.0", "add.vertices()", "add_vertices()")
   add_vertices(graph = graph, nv = nv, attr = attr, ...)
 } # nocov end
@@ -64,12 +67,13 @@ add.vertices <- function(graph, nv, ..., attr = list()) { # nocov start
 #' @description
 #' `r lifecycle::badge("deprecated")`
 #'
-#' `add.edges()` was renamed to `add_edges()` to create a more
+#' `add.edges()` was renamed to [add_edges()] to create a more
 #' consistent API.
 #' @inheritParams add_edges
 #' @keywords internal
 #' @export
-add.edges <- function(graph, edges, ..., attr = list()) { # nocov start
+add.edges <- function(graph, edges, ..., attr = list()) {
+  # nocov start
   lifecycle::deprecate_soft("2.0.0", "add.edges()", "add_edges()")
   add_edges(graph = graph, edges = edges, attr = attr, ...)
 } # nocov end
@@ -147,7 +151,11 @@ add_edges <- function(graph, edges, ..., attr = list()) {
 
   edges.orig <- ecount(graph)
   on.exit(.Call(R_igraph_finalizer))
-  graph <- .Call(R_igraph_add_edges_manual, graph, as_igraph_vs(graph, edges) - 1)
+  graph <- .Call(
+    R_igraph_add_edges_manual,
+    graph,
+    as_igraph_vs(graph, edges) - 1
+  )
   edges.new <- ecount(graph)
 
   if (edges.new - edges.orig != 0) {
@@ -341,25 +349,14 @@ ecount <- gsize
 #' intersection(n1, n34)
 neighbors <- function(graph, v, mode = c("out", "in", "all", "total")) {
   ensure_igraph(graph)
-  if (is.character(mode)) {
-    mode <- igraph.match.arg(mode)
-    mode <- switch(mode,
-      "out" = 1,
-      "in" = 2,
-      "all" = 3,
-      "total" = 3
-    )
-  }
+  mode <- igraph.match.arg(mode)
+
   v <- as_igraph_vs(graph, v)
   if (length(v) == 0) {
     stop("No vertex was specified")
   }
-  on.exit(.Call(R_igraph_finalizer))
-  res <- .Call(R_igraph_neighbors, graph, v - 1, as.numeric(mode)) + 1L
 
-  if (igraph_opt("return.vs.es")) res <- create_vs(graph, res)
-
-  res
+  neighbors_impl(graph, vid = v, mode = mode)
 }
 
 #' Incident edges of a vertex in a graph
@@ -383,12 +380,7 @@ incident <- function(graph, v, mode = c("all", "out", "in", "total")) {
   ensure_igraph(graph)
   if (is_directed(graph)) {
     mode <- igraph.match.arg(mode)
-    mode <- switch(mode,
-      "out" = 1,
-      "in" = 2,
-      "all" = 3,
-      "total" = 3
-    )
+    mode <- switch(mode, "out" = 1, "in" = 2, "all" = 3, "total" = 3)
   } else {
     mode <- 1
   }
@@ -399,7 +391,9 @@ incident <- function(graph, v, mode = c("all", "out", "in", "total")) {
   on.exit(.Call(R_igraph_finalizer))
   res <- .Call(R_igraph_incident, graph, v - 1, as.numeric(mode)) + 1L
 
-  if (igraph_opt("return.vs.es")) res <- create_es(graph, res)
+  if (igraph_opt("return.vs.es")) {
+    res <- create_es(graph, res)
+  }
 
   res
 }
@@ -467,6 +461,48 @@ get.edges <- function(graph, es) {
   ends(graph, es, names = FALSE)
 }
 
+el_to_vec <- function(x, call = rlang::caller_env()) {
+  if (is.data.frame(x)) {
+    if (typeof(x[[1]]) == typeof(x[[2]])) {
+      c(rbind(x[[1]], x[[2]]))
+    } else {
+      cli::cli_abort(
+        "The columns of the data.frame are of different type ({typeof(x[[1]])} and {typeof(x[[2]])}) "
+      )
+    }
+  } else if (inherits(x, "matrix")) {
+    dimx <- dim(x)
+    nrow <- dimx[[1]]
+    ncol <- dimx[[2]]
+    if (nrow == 2 && ncol == 2) {
+      lifecycle::deprecate_stop(
+        "2.1.5",
+        "get_edge_ids(vp = 'is not allowed to be a 2 times 2 matrix')"
+      )
+    } else if (nrow == 2) {
+      lifecycle::deprecate_warn(
+        "2.1.5",
+        "get_edge_ids(vp = 'supplied as a matrix should be a n times 2 matrix, not 2 times n')",
+        details = "either transpose the matrix with t() or convert it to a data.frame with two columns."
+      )
+      c(x)
+    } else if (ncol == 2) {
+      c(t(x))
+    } else {
+      cli::cli_abort(
+        "{.args vp} was supplied as a {dimx[1]} times {dimx[2]} matrix. Only n times 2 matrices are allowed"
+      )
+    }
+  } else if (is.vector(x)) {
+    x
+  } else {
+    cli::cli_abort(
+      "Only two-column data.frames and matrices, and vectors are allowed for {.args vp}",
+      call = call
+    )
+  }
+}
+
 
 #' Find the edge ids based on the incident vertices of the edges
 #'
@@ -482,8 +518,9 @@ get.edges <- function(graph, es) {
 #' vertices.
 #'
 #' @param graph The input graph.
-#' @param vp The incident vertices, given as vertex ids or symbolic vertex
-#'   names. They are interpreted pairwise, i.e. the first and second are used for
+#' @param vp The incident vertices, given as a two-column data frame, two-column matrix,
+#'   or vector of vertex ids or symbolic vertex names.
+#'   For a vector, the values are interpreted pairwise, i.e. the first and second are used for
 #'   the first edge, the third and fourth for the second, etc.
 #' @param directed Logical scalar, whether to consider edge directions in
 #'   directed graphs. This argument is ignored for undirected graphs.
@@ -513,17 +550,20 @@ get.edges <- function(graph, es) {
 #' eis
 #' E(g)[eis]
 #'
-get_edge_ids <- function(graph,
-                         vp,
-                         directed = TRUE,
-                         error = FALSE) {
+get_edge_ids <- function(graph, vp, directed = TRUE, error = FALSE) {
   ensure_igraph(graph)
 
+  vp <- el_to_vec(vp, call = rlang::caller_env())
+
   on.exit(.Call(R_igraph_finalizer))
   .Call(
-    R_igraph_get_eids, graph, as_igraph_vs(graph, vp) - 1,
-    as.logical(directed), as.logical(error)
-  ) + 1
+    R_igraph_get_eids,
+    graph,
+    as_igraph_vs(graph, vp) - 1,
+    as.logical(directed),
+    as.logical(error)
+  ) +
+    1
 }
 
 #' Find the edge ids based on the incident vertices of the edges
@@ -531,19 +571,20 @@ get_edge_ids <- function(graph,
 #' @description
 #' `r lifecycle::badge("deprecated")`
 #'
-#' `get.edge.ids()` was renamed to `get_edge_ids()` to create a more
+#' `get.edge.ids()` was renamed to [get_edge_ids()] to create a more
 #' consistent API.
 #' @inheritParams get_edge_ids
 #' @param multi
 #'   `r lifecycle::badge("deprecated")`
 #' @keywords internal
 #' @export
-get.edge.ids <- function(graph,
-                         vp,
-                         directed = TRUE,
-                         error = FALSE,
-                         multi = deprecated()) {
-
+get.edge.ids <- function(
+  graph,
+  vp,
+  directed = TRUE,
+  error = FALSE,
+  multi = deprecated()
+) {
   if (lifecycle::is_present(multi)) {
     if (isTRUE(multi)) {
       lifecycle::deprecate_stop("2.0.0", "get.edge.ids(multi = )")
@@ -596,28 +637,24 @@ gorder <- vcount
 #' @examples
 #' g <- make_graph("Zachary")
 #' adjacent_vertices(g, c(1, 34))
-adjacent_vertices <- function(graph, v,
-                              mode = c("out", "in", "all", "total")) {
+adjacent_vertices <- function(graph, v, mode = c("out", "in", "all", "total")) {
   ensure_igraph(graph)
 
   vv <- as_igraph_vs(graph, v) - 1
-  mode <- switch(match.arg(mode),
-    "out" = 1,
-    "in" = 2,
-    "all" = 3,
-    "total" = 3
-  )
+  mode <- switch(match.arg(mode), "out" = 1, "in" = 2, "all" = 3, "total" = 3)
 
   on.exit(.Call(R_igraph_finalizer))
 
   res <- .Call(R_igraph_adjacent_vertices, graph, vv, mode)
+  res <- lapply(res, `+`, 1)
 
   if (igraph_opt("return.vs.es")) {
-    res <- lapply(res, `+`, 1)
     res <- lapply(res, unsafe_create_vs, graph = graph, verts = V(graph))
   }
 
-  if (is_named(graph)) names(res) <- V(graph)$name[vv + 1]
+  if (is_named(graph)) {
+    names(res) <- V(graph)$name[vv + 1]
+  }
 
   res
 }
@@ -639,28 +676,24 @@ adjacent_vertices <- function(graph, v,
 #' @examples
 #' g <- make_graph("Zachary")
 #' incident_edges(g, c(1, 34))
-incident_edges <- function(graph, v,
-                           mode = c("out", "in", "all", "total")) {
+incident_edges <- function(graph, v, mode = c("out", "in", "all", "total")) {
   ensure_igraph(graph)
 
   vv <- as_igraph_vs(graph, v) - 1
-  mode <- switch(match.arg(mode),
-    "out" = 1,
-    "in" = 2,
-    "all" = 3,
-    "total" = 3
-  )
+  mode <- switch(match.arg(mode), "out" = 1, "in" = 2, "all" = 3, "total" = 3)
 
   on.exit(.Call(R_igraph_finalizer))
 
   res <- .Call(R_igraph_incident_edges, graph, vv, mode)
+  res <- lapply(res, `+`, 1)
 
   if (igraph_opt("return.vs.es")) {
-    res <- lapply(res, `+`, 1)
     res <- lapply(res, unsafe_create_es, graph = graph, es = E(graph))
   }
 
-  if (is_named(graph)) names(res) <- V(graph)$name[vv + 1]
+  if (is_named(graph)) {
+    names(res) <- V(graph)$name[vv + 1]
+  }
 
   res
 }
