@@ -1,8 +1,7 @@
-
 #   IGraph R package
 #   Copyright (C) 2005-2012  Gabor Csardi <csardi.gabor@gmail.com>
 #   334 Harvard street, Cambridge, MA 02139 USA
-#   
+#
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
 #   the Free Software Foundation; either version 2 of the License, or
@@ -12,7 +11,7 @@
 #   but WITHOUT ANY WARRANTY; without even the implied warranty of
 #   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #   GNU General Public License for more details.
-#   
+#
 #   You should have received a copy of the GNU General Public License
 #   along with this program; if not, write to the Free Software
 #   Foundation, Inc.,  51 Franklin Street, Fifth Floor, Boston, MA
@@ -21,15 +20,7 @@
 ###################################################################
 
 .onAttach <- function(library, pkg) {
-    ## we can't do this in .onLoad
-    unlockBinding(".igraph.pars", asNamespace("igraph"))
-    unlockBinding(".igraph.pb", asNamespace("igraph"))
-    invisible()
-}
-
-.Call <- function(.NAME, ...) {
-  if (.NAME != "R_igraph_finalizer") {
-    base::.Call("R_igraph_check_finally_stack", PACKAGE="igraph")
-  }
-  base::.Call(.NAME, ...)
+  ## we can't do this in .onLoad
+  unlockBinding(".igraph.pb", asNamespace("igraph"))
+  invisible()
 }
