@@ -1,4 +1,3 @@
-
 ## ----------------------------------------------------------------------
 ##
 ##   IGraph R package
@@ -31,7 +30,9 @@
   gal <- graph_attr_names(object)
   if (length(gal) != 0) {
     ga <- paste(
-      sep = "", gal, " (g/",
+      sep = "",
+      gal,
+      " (g/",
       .Call(R_igraph_get_attr_mode, object, 2L),
       ")"
     )
@@ -39,7 +40,9 @@
   val <- vertex_attr_names(object)
   if (length(val) != 0) {
     va <- paste(
-      sep = "", val, " (v/",
+      sep = "",
+      val,
+      " (v/",
       .Call(R_igraph_get_attr_mode, object, 3L),
       ")"
     )
@@ -47,7 +50,9 @@
   eal <- edge_attr_names(object)
   if (length(eal) != 0) {
     ea <- paste(
-      sep = "", edge_attr_names(object), " (e/",
+      sep = "",
+      edge_attr_names(object),
+      " (e/",
       .Call(R_igraph_get_attr_mode, object, 4L),
       ")"
     )
@@ -73,14 +78,19 @@
   )
   w <- getOption("width")
   if (nchar(title) < w && "name" %in% graph_attr_names(object)) {
-    title <- substring(paste(sep = "", title, as.character(object$name)[1]), 1, w - 1)
+    title <- substring(
+      paste(sep = "", title, as.character(object$name)[1]),
+      1,
+      w - 1
+    )
   }
   cat(title, "\n", sep = "")
 
   atxt <- .get.attr.codes(object)
   atxt <- paste(atxt[atxt != ""], collapse = ", ")
   if (atxt != "") {
-    atxt <- strwrap(paste(sep = "", "+ attr: ", atxt),
+    atxt <- strwrap(
+      paste(sep = "", "+ attr: ", atxt),
       prefix = "| ",
       initial = ""
     )
@@ -135,7 +145,9 @@
 
 .print.vertex.attributes <- function(x, full, max.lines) {
   pf <- function(x) .print.vertex.attributes.old(x, full, max.lines)
-  if (length(vertex_attr_names(x))) cat("+ vertex attributes:\n")
+  if (length(vertex_attr_names(x))) {
+    cat("+ vertex attributes:\n")
+  }
   indent_print(x, .indent = "| ", .printer = pf)
 }
 
@@ -152,12 +164,14 @@
       omitted.vertices <- vc - mp
       ind <- seq(length.out = mp)
     }
-    if (vc == 0 ||
-      all(sapply(list, function(v) {
-        is.numeric(vertex_attr(x, v)) ||
-          is.character(vertex_attr(x, v)) ||
-          is.logical(vertex_attr(x, v))
-      }))) {
+    if (
+      vc == 0 ||
+        all(sapply(list, function(v) {
+          is.numeric(vertex_attr(x, v)) ||
+            is.character(vertex_attr(x, v)) ||
+            is.logical(vertex_attr(x, v))
+        }))
+    ) {
       ## create a table
       tab <- data.frame(v = paste(sep = "", "[", ind, "]"), row.names = "v")
       for (i in list) {
@@ -177,7 +191,8 @@
     if (omitted.vertices != 0) {
       cat(paste(
         '[ reached getOption("max.print") -- omitted',
-        omitted.vertices, "vertices ]\n\n"
+        omitted.vertices,
+        "vertices ]\n\n"
       ))
     }
   }
@@ -196,11 +211,16 @@
   if (names && !"name" %in% vertex_attr_names(x)) {
     names <- FALSE
   }
-  if (names && "name" %in% vertex_attr_names(x) &&
-    !is.numeric(vertex_attr(x, "name")) &&
-    !is.character(vertex_attr(x, "name")) &&
-    !is.logical(vertex_attr(x, "name"))) {
-    cli::cli_warn("Can't print vertex names, complex {.val name} vertex attribute.")
+  if (
+    names &&
+      "name" %in% vertex_attr_names(x) &&
+      !is.numeric(vertex_attr(x, "name")) &&
+      !is.character(vertex_attr(x, "name")) &&
+      !is.logical(vertex_attr(x, "name"))
+  ) {
+    cli::cli_warn(
+      "Can't print vertex names, complex {.val name} vertex attribute."
+    )
     names <- FALSE
   }
 
@@ -220,12 +240,14 @@
   } else {
     seq(length.out = nrow(el))
   }
-  if (ec == 0 ||
-    all(sapply(list, function(v) {
-      is.numeric(edge_attr(x, v)) |
-        is.character(edge_attr(x, v)) |
-        is.logical(edge_attr(x, v))
-    }))) {
+  if (
+    ec == 0 ||
+      all(sapply(list, function(v) {
+        is.numeric(edge_attr(x, v)) |
+          is.character(edge_attr(x, v)) |
+          is.logical(edge_attr(x, v))
+      }))
+  ) {
     ## create a table
     tab <- data.frame(row.names = paste(sep = "", "[", ename, "]"))
     if (is.numeric(el)) {
@@ -234,8 +256,10 @@
       w <- max(nchar(el))
     }
     tab["edge"] <- paste(
-      sep = "", format(el[, 1], width = w),
-      arrow, format(el[, 2], width = w)
+      sep = "",
+      format(el[, 1], width = w),
+      arrow,
+      format(el[, 2], width = w)
     )
     for (i in list) {
       tab[i] <- edge_attr(x, i)
@@ -255,30 +279,36 @@
   }
   if (omitted.edges != 0) {
     cat(paste(
-      '[ reached getOption("max.print") -- omitted', omitted.edges,
+      '[ reached getOption("max.print") -- omitted',
+      omitted.edges,
       "edges ]\n\n"
     ))
   }
 }
 
-.print.edges.compressed <- function(x,
-                                    edges = E(x),
-                                    names,
-                                    num = FALSE,
-                                    max.lines = igraph_opt("auto.print.lines"),
-                                    id = igraph_opt("print.id")) {
+.print.edges.compressed <- function(
+  x,
+  edges = E(x),
+  names,
+  num = FALSE,
+  max.lines = igraph_opt("auto.print.lines"),
+  id = igraph_opt("print.id")
+) {
   len <- length(edges)
   gid <- graph_id(edges)
 
   title <- "+" %+%
     (if (num) {
-      " " %+% chr(len) %+% "/" %+%
-        (if (is.null(x)) "?" else chr(gsize(x)))
+      " " %+% chr(len) %+% "/" %+% (if (is.null(x)) "?" else chr(gsize(x)))
     } else {
       ""
     }) %+%
     (if (len == 1) " edge" else " edges") %+%
-    (if (isTRUE(id) && !is.na(gid)) paste(" from", substr(gid, 1, 7)) else "") %+%
+    (if (isTRUE(id) && !is.na(gid)) {
+      paste(" from", substr(gid, 1, 7))
+    } else {
+      ""
+    }) %+%
     (if (is.null(x)) " (deleted)" else "") %+%
     (if (is.null(attr(edges, "vnames"))) "" else " (vertex names)") %+%
     ":\n"
@@ -353,8 +383,10 @@
       } else if (q == "max") {
         can_max <<- no
       } else if (q == "done") {
-        if (no["tried_items"] < length(edges) ||
-          no["printed_lines"] < no["tried_lines"]) {
+        if (
+          no["tried_items"] < length(edges) ||
+            no["printed_lines"] < no["tried_lines"]
+        ) {
           cat("+ ... omitted several edges\n")
         }
       }
@@ -435,7 +467,6 @@ print_all <- function(object, ...) {
 }
 
 
-
 #' Print graphs to the terminal
 #'
 #' These functions attempt to print a graph to the terminal in a human readable
@@ -516,13 +547,17 @@ print_all <- function(object, ...) {
 #' g
 #' summary(g)
 #'
-print.igraph <- function(x, full = igraph_opt("print.full"),
-                         graph.attributes = igraph_opt("print.graph.attributes"),
-                         vertex.attributes = igraph_opt("print.vertex.attributes"),
-                         edge.attributes = igraph_opt("print.edge.attributes"),
-                         names = TRUE, max.lines = igraph_opt("auto.print.lines"),
-                         id = igraph_opt("print.id"),
-                         ...) {
+print.igraph <- function(
+  x,
+  full = igraph_opt("print.full"),
+  graph.attributes = igraph_opt("print.graph.attributes"),
+  vertex.attributes = igraph_opt("print.vertex.attributes"),
+  edge.attributes = igraph_opt("print.edge.attributes"),
+  names = TRUE,
+  max.lines = igraph_opt("auto.print.lines"),
+  id = igraph_opt("print.id"),
+  ...
+) {
   ensure_igraph(x)
 
   head_lines <- .print.header(x, id)
